T11

Struct T11 

pub struct T11<A, B, C, D, E, F, G, H, I, J, K>(pub A, pub B, pub C, pub D, pub E, pub F, pub G, pub H, pub I, pub J, pub K);
11-ary tuple wrapper

Tuple Fields

0: A1: B2: C3: D4: E5: F6: G7: H8: I9: J10: K